@@ -1,7 +1,7 @@
-"EDhelper" <- function(parmVec, respl, reference, type, cond = TRUE)
+"EDhelper" <- function(parmVec, respl, reference, typeCalc, cond = TRUE)
 {
     ## Converting absolute to relative
-    if (type == "absolute") 
+    if (typeCalc == "absolute") 
     {
         p <- 100 * ((parmVec[3] - respl) / (parmVec[3] - parmVec[2]))
     } else {  
@@ -10,12 +10,12 @@
     ## Swapping p for an increasing curve
     if (cond)
     {
-        if ((type == "relative") && (parmVec[1] < 0) && (reference == "control"))
+        if ((typeCalc == "relative") && (parmVec[1] < 0) && (reference == "control"))
         {
             p <- 100 - p
         }
     } else {
-        if ((type == "relative") && (reference == "control"))
+        if ((typeCalc == "relative") && (reference == "control"))
         {
             p <- 100 - p
         }
